# -*- coding: utf-8 -*-
###############################################################################
#   Copyright (c) 2019 Eynes S.R.L (Marco Folco)
#   License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).
###############################################################################

import logging
import datetime

from odoo import models, fields, api, _
from odoo.exceptions import ValidationError, UserError

_logger = logging.getLogger(__name__)


class LotNumber(models.Model):
    _name = 'lot.number'
    _description = 'Lot numbers for medical benefits'
    _rec_name = 'value'

    insurance_plan_id = fields.Many2one('health.insurance.plan', ondelete='cascade')
    value = fields.Char('Value', required=True)
    presentation_date = fields.Date('Presentation date')
    state = fields.Selection(
            [
                ('active', 'Active'),
                ('invoiced', 'Invoiced'),
            ],
            default="active"
    )

    @api.constrains('presentation_date')
    def check_presentation_date(self):
        bdate = self.presentation_date
        if bdate:
            if bdate.isoweekday() == 7:
                raise ValidationError(_('Presentation date can not be Sunday'))

