# -*- coding: utf-8 -*-
###############################################################################
#   Copyright (c) 2020 Eynes S.R.L (Marco Folco)
#   License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).
###############################################################################

import logging
import datetime

from odoo import models, fields, api, _
from odoo.exceptions import ValidationError, UserError


_logger = logging.getLogger(__name__)

class ResPartner(models.Model):
    _inherit = 'res.partner'

    @api.model
    def create(self, vals):
        rpi = self.env['res.partner.insurance']
        hip = self.env['health.insurance.plan']
        insurance_lines = [(5,0,0)]
        if 'partner_type' in vals:
            if vals['partner_type'] == 'patient':
                if 'insurance_plan_id' in self.env.context:
                    ipd = self.env.context.get('insurance_plan_id')
                    ip = hip.browse(ipd)
                    if ip.insurance_id.id == self.env.ref('health_insurance.res_partner_pami').id:
                        ipd = ip.insurance_id.main_insurance_plan_id.id
                    insurance = (0,0,{
                            'insurance_plan_id': ipd,
                            'is_main': True,
                    })
                    insurance_lines.append(insurance)
                    vals['health_insurance_ids'] = insurance_lines
        return super(ResPartner, self).create(vals)

    @api.model
    def default_get(self, fields_list):
        res = super(ResPartner, self).default_get(fields_list)
        if 'name' in res.keys():
            if res['name'].isdigit():
                res['vat'] = res['name']
                res.pop('name',None)
        return res

    @api.model
    def _name_search(self, name, args=None, operator='ilike', limit=100, name_get_uid=None):
        if 'no_repeat' in args:
            repeat = 0
            args.remove('no_repeat')
            del args[0]
        else:
            repeat = 1
        res = super()._name_search(name=name, args=args, operator=operator, limit=limit, name_get_uid=name_get_uid)
        if self.env.context.get('from_practice') and len(res) == 0:
            args.append('no_repeat')
            if repeat:
                res = self._name_search(name=name, args=args, operator=operator, limit=limit, name_get_uid=name_get_uid)
        return res
