from odoo import models, _, api
import logging
_logger = logging.getLogger(__name__)

class ReportGroupBenefits(models.AbstractModel):

    _name = 'report.medical_benefit.report_group_benefits_template'

    @api.model
    def _get_report_values(self, docids, data=None):
        data = data if data is not None else {}
        mb = self.env['medical.benefit']
        self.env.cr.execute(
                "SELECT DISTINCT ON(ln.value,hip.ref,rp.ref,mb.descriptor_id) hip.id as ins_id,CONCAT(hip.ref,' - ',hip.name) as ins,"
                "ln.id as ln_id,ln.value as ln_value,ln.presentation_date as ln_date,rp.id as pro_id,CONCAT(rp.ref,' - ',rp.name) as prof,rp.display_name,mb.descriptor_id as desc_id "
                "FROM medical_benefit mb JOIN "
                "res_partner rp ON rp.id = mb.professional_id JOIN "
                "health_insurance_plan hip ON hip.id = mb.insurance_plan_id LEFT JOIN "
                "lot_number ln ON ln.id = mb.lot_number_id "
                "WHERE mb.state = 'for_invoicing' AND hip.id IN %s and ln.id IN %s "
                "ORDER BY ln.value DESC,hip.ref,rp.ref,mb.descriptor_id ",
                [tuple(data['hip_ids']),tuple(data['ln_ids'])]
        )
        records = dict()
        lot_dates = dict()
        insurance = ""
        lot_number = ""
        professional = ""
        # l[1] is insurance ref
        # l[3] is lot number value
        # l[5] is professional enrollment code
        for l in self.env.cr.dictfetchall():
            if l['ln_value'] not in lot_dates:
                lot_dates[l['ln_value']] = l['ln_date']
            benefits = mb.search([('id','in',data['benef_ids']),('insurance_plan_id','=',l['ins_id']),('lot_number_id','=',l['ln_id']),('professional_id','=',l['pro_id']),('descriptor_id','=',l['desc_id']),('state','=','for_invoicing')])
            if len(benefits) > 0:
                if l['ln_value'] != lot_number:
                    lot_number = l['ln_value']
                    records[lot_number] = dict()
                    insurance = ""
                    professional = ""
                if l['ins'] != insurance:
                    insurance = l['ins']
                    records[lot_number][insurance] = dict()
                    professional = ""
                if l['prof'] != professional:
                    professional = l['prof']
                    records[lot_number][insurance][professional] = dict()
                descriptor = l['desc_id']
                records[lot_number][insurance][professional][descriptor] = list()
                for b in benefits:
                    records[lot_number][insurance][professional][descriptor].append({
                        'order_number': b.order_number,
                        'patient': b.patient_id.display_name,
                        'descriptor': b.descriptor_id.name_os,
                        'lens': b.lens_code,
                    })
        return {
            'doc_ids': data.get('ids', data.get('active_ids')),
            'doc_model': 'medical.benefit',
            'records': records,
            'lot_dates': lot_dates,
        }
