# -*- coding: utf-8 -*-
###############################################################################
#   Copyright (c) 2020 Eynes / E-Mips (Marco Folco)
#   License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).
###############################################################################

import logging
import base64
import csv
import io
import resource
from datetime import datetime

from odoo import models, api, fields, _, exceptions
from odoo.tools import config
# from odoo.exceptions import except_orm
# from odoo.addons.decimal_precision import decimal_precision as dp
# from odoo.tools import DEFAULT_SERVER_DATE_FORMAT, \
#         DEFAULT_SERVER_DATETIME_FORMAT, float_compare


_logger = logging.getLogger(__name__)

class WizardGroupBenefits(models.TransientModel):
    _name = 'wizard.group.benefits'
    _description = 'Wizard for grouping benefits'

    state = fields.Selection(
            [
                ('init', 'Init'),
                ('report','Report'),
            ],
            string='State',
            default='init',
    )
    insurance_ids = fields.Many2many('health.insurance.plan',string='Insurances',domain=lambda x:x.get_insurance_domain())
    lot_number_ids = fields.Many2many('lot.number',string='Lot Numbers',domain=lambda x:x.get_lot_number_domain())

    @api.multi
    def get_insurance_domain(self):
        domain_insurance_ids = []
        query = """
        SELECT DISTINCT(insurance_plan_id) as insurance_id
        FROM medical_benefit
        WHERE state = 'for_invoicing'
        """
        self.env.cr.execute(query)
        for val in self.env.cr.dictfetchall():
            domain_insurance_ids.append(val['insurance_id'])
        return [('id','in',domain_insurance_ids)]

    @api.multi
    def get_lot_number_domain(self):
        return [('insurance_id','in',self.insurance_ids.ids)]



    @api.onchange('insurance_ids')
    def onchange_insurance_ids(self):
        insurance_ids = self.insurance_ids.ids
        for ln in self.lot_number_ids:
            if ln.insurance_plan_id.id not in insurance_ids:
                self.lot_number_ids = [(3,ln.id)]
        return {
            'domain': {
                'lot_number_ids': [('insurance_plan_id','in',insurance_ids)],
            }
        }

    @api.multi
    def button_generate_view(self):
        medical_benefit = self.env['medical.benefit']
        benefits = medical_benefit.search([('state','=','for_invoicing')])
        context = dict()
        context.update(self.env.context)
        context.update({'group_by': ['insurance_plan_id', 'lot_number_id', 'professional_id']})
        action = self.env.ref('medical_benefit.medical_benefit_action').read()[0]
        action['domain'] = str([('id','in',benefits.ids)])
        action['context'] = context
        return action

    @api.multi
    def button_configurate_report(self):
        medical_benefit = self.env['medical.benefit']
       
        self.write({
            'state': 'report',
        })
        return {
                'context': self.env.context,
                'view_type': 'form',
                'view_mode': 'form',
                'res_model': 'wizard.group.benefits',
                'res_id': self.id,
                'view_id': False,
                'type': 'ir.actions.act_window',
                'target': 'new',
            }


    @api.multi
    def button_generate_report(self):
        medical_benefit = self.env['medical.benefit']
        ln_ids = self.lot_number_ids.ids
        hip_ids = self.insurance_ids.ids
        benefits = medical_benefit.search([('state','=','for_invoicing'),('lot_number_id','in',ln_ids),('insurance_plan_id','in',hip_ids)])
        data = {
                'ids': self.ids,
                'model': self._name,
                'user': self.env.user,
                'benef_ids': benefits.ids,
                'ln_ids': ln_ids,
                'hip_ids': hip_ids,
        }
        return self.env.ref('medical_benefit.report_group_benefits').report_action(self, data=data)

