# -*- coding: utf-8 -*-
###############################################################################
#   Copyright (c) 2020 Eynes / E-Mips (Marco Folco)
#   License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).
###############################################################################

import logging
import base64
import csv
import io
import resource
from datetime import datetime
from odoo.exceptions import ValidationError

from odoo import models, api, fields, _, exceptions
from odoo.tools import config
# from odoo.exceptions import except_orm
# from odoo.addons.decimal_precision import decimal_precision as dp
# from odoo.tools import DEFAULT_SERVER_DATE_FORMAT, \
#         DEFAULT_SERVER_DATETIME_FORMAT, float_compare


_logger = logging.getLogger(__name__)


class WizardValidateBenefit(models.TransientModel):
    _name = 'wizard.validate.benefit'
    _description = 'Wizard for validating benefits'

    insurance_plan_id = fields.Many2one('health.insurance.plan','Health Insurance')
    date_from = fields.Date('Date from')
    date_to = fields.Date('Date to')

    @api.multi
    def check_date(self):
        if self.date_from > self.date_to:
            raise ValidationError(_("Date from must be smaller than date to or equal"))

    @api.multi
    def button_validate(self):
        mb = self.env['medical.benefit']
        benefit_ids = []
        self.check_date()
        df = self.date_from.strftime("%Y-%m-%d %I:%M:%S")
        dt = self.date_to.strftime("%Y-%m-%d %I:%M:%S")
        benefits = mb.search([
            ('insurance_plan_id','=',self.insurance_plan_id.id),
            ('benefit_date','>=',df),
            ('benefit_date','<=',dt),
            ('state','in',['draft_sofsa','draft_clinic','invalid']),
        ])
        for benefit in benefits:
            benefit.validate_benefit()
            if benefit.state == 'invalid':
                benefit_ids.append(benefit.id)
        return {
            'name': _('Invalid benefits'),
            'context': self.env.context,
            'view_type': 'form',
            'view_mode': 'tree,form',
            'res_model': 'medical.benefit',
            'type': 'ir.actions.act_window',
            'domain': [('id','in',benefit_ids)],
        }

